@@ -20,6 +20,7 @@
 #' \describe{
 #' \item{VaR}{Calculated Value at Risk}
 #' \item{ES}{Calculated Expected Shortfall (Conditional Value at Risk)}
+#' \item{p}{Confidence level for VaR calculation}
 #' \item{garchmod}{The model fit. Is the respective GARCH fit for
 #' \code{model = 'GARCH'} (see \code{rugarch} documentation) and  \code{'EWMA'} for
 #' \code{model = 'EWMA'}}
@@ -76,6 +77,6 @@ vwhs <- function(x, p = 0.975, model = c("EWMA", "GARCH"), lambda = 0.94, ...)
     loss <- -(xz * csig[n])
     VaR <- unname(stats::quantile(loss, p))
     ES <- mean(loss[loss > VaR])
-    results <- list(VaR = VaR, ES = ES, garchmod = fit)
+    results <- list(VaR = VaR, ES = ES, p = p, garchmod = fit)
     results
 }
